@@ -2,18 +2,16 @@ package HTML::Hyphenate;    # -*- cperl; cperl-indent-level: 4 -*-
 use strict;
 use warnings;
 
-## no critic qw(ProhibitLongLines)
-# $Id: Hyphenate.pm 321 2010-10-30 18:06:08Z roland $
-# $Revision: 321 $
+# $Id: Hyphenate.pm 387 2010-12-21 19:41:17Z roland $
+# $Revision: 387 $
 # $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/elaine/trunk/HTML-Hyphenate/lib/HTML/Hyphenate.pm $
-# $Date: 2010-10-30 20:06:08 +0200 (Sat, 30 Oct 2010) $
-## use critic
+# $Date: 2010-12-21 20:41:17 +0100 (Tue, 21 Dec 2010) $
 
 use 5.006000;
 use utf8;
 use charnames qw(:full);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Log::Log4perl qw(:easy get_logger);
 use Set::Scalar;
@@ -87,7 +85,7 @@ class {
     has min_pre          => ( is => 'integer', default => $DEFAULT_MIN_PRE );
     has min_post         => ( is => 'integer', default => $DEFAULT_MIN_POST );
     has output_xml       => ( is => 'integer', default => $DEFAULT_XML );
-    has default_lang     => ( is => 'integer', default => $DEFAULT_LANG );
+    has default_lang     => ( is => 'string', default => $DEFAULT_LANG );
     has default_included => ( is => 'integer', default => $DEFAULT_INCLUDED );
     has classes_included => ( is => 'arrayref', default => [] );
     has classes_excluded => ( is => 'arrayref', default => [] );
@@ -96,244 +94,266 @@ class {
     has _lang => ( is => 'string', view => 'PRIVATE' );
     has _tree => ( is => 'tree',   view => 'PRIVATE' );
 
-    method hyphenated => sub {
-        my ( $self, $html ) = @_;
-        if ( defined $html ) {
-            $log->debug( sprintf $LOG_HTML_METHOD, $html );
-            $self->html($html);
-        }
-        else {
-            $log->debug( sprintf $LOG_HTML_PROPERTY, $self->html );
-        }
-        if ( defined $self->html ) {
-            $self->_traverse_html();
-            return $self->_clean_html();
-        }
-        else {
-            $log->warn($LOG_HTML_UNDEF);
-            return;
-        }
-    };
+    method hyphenated => \&__hyphenated;
 
     method _traverse_html => (
-        code => sub {
-            my ($self) = @_;
-            $self->_reset_tree;
-            $self->_tree->parse_content( $self->html );
-            $self->_tree->objectify_text();
-            $self->_tree->traverse(
-                [
-                    sub {
-                        my $element = $_[0];
-                        $log->debug( sprintf $LOG_TRAVERSE, $element->tag() );
-                        $self->_configure_lang($element);
-                        if ( $element->attr($TEXT) ) {
-                            if ( $self->_hyphenable($element) ) {
-                                $log->debug(
-                                    sprintf $LOG_TEXT_NODE,
-                                    $element->attr($TEXT)
-                                );
-                                $element->attr( $TEXT,
-                                    $self->_hyphen( $element->attr($TEXT) ) );
-                            }
-                        }
-                        else {
-                            foreach
-                              my $attr ( $element->all_external_attr_names() )
-                            {
-                                if ( $text_attr->has($attr) ) {
-                                    $element->attr( $attr,
-                                        $self->_hyphen( $element->attr($attr) )
-                                    );
-                                }
-                            }
-                        }
-                        ## no critic qw(RequireExplicitInclusion ProhibitCallsToUnexportedSubs)
-                        return HTML::Element::OK;
-                        ## use critic
-                    },
-                    undef
-                ]
-            );
-        },
+        code => \&__traverse_html,
         view => 'PRIVATE',
     );
 
     method _clean_html => (
-        code => sub {
-            my ($self) = @_;
-            $self->_tree->deobjectify_text();
-            my $html =
-                $self->output_xml
-              ? $self->_tree->as_XML()
-              : $self->_tree->as_HTML( $HTML_ESCAPE, $EMPTY, {} );
-            $self->_reset_tree;
-            $html =~ s/$ROOT/$1/xgism;
-            return $html;
-        },
+        code => \&__clean_html,
         view => 'PRIVATE',
     );
 
     method _hyphen => (
-        code => sub {
-            my ( $self, $text ) = @_;
-            $log->debug( sprintf $LOG_HYPHEN_TEXT, $text );
-            $text =~
-              s/(\w{@{[$self->min_length]},})/$self->_hyphen_word($1)/xsmeg;
-            return $text;
-        },
+        code => \&__hyphen,
         view => 'PRIVATE',
     );
 
     method _hyphen_word => (
-        code => sub {
-            my ( $self, $word ) = @_;
-            if ( defined $self->_hyphenators->{ $self->_lang } ) {
-                $log->debug( sprintf $LOG_HYPHEN_WORD,
-                    $word,
-                    $self->_hyphenators->{ $self->_lang }->visualize($word) );
-                my $number = 0;
-                foreach my $pos (
-                    $self->_hyphenators->{ $self->_lang }->hyphenate($word) )
-                {
-                    substr $word, $pos + $number, 0, $SOFT_HYPHEN;
-                    $number += length $SOFT_HYPHEN;
-                }
-            }
-            else {
-                $log->warn( sprintf $LOG_NOT_HYPHEN, $self->_lang );
-            }
-            return $word;
-        },
+        code => \&__hyphen_word,
         view => 'PRIVATE',
     );
 
     method _configure_lang => (
-        code => sub {
-            my ( $self, $element ) = @_;
-            my $lang = $element->attr_get_i($LANG);
-            $lang ||= $element->attr_get_i(qq{xml:$LANG});
-            my %hyphen_opts = (
-                leftmin  => $self->min_pre,
-                rightmin => $self->min_post,
-            );
-            defined $self->style && ( $hyphen_opts{style} = $self->style );
-            defined $lang || ( $lang = $self->default_lang );
-            if ( !defined $self->_lang || $lang ne $self->_lang ) {
-                $self->_lang($lang);
-                $log->debug( sprintf $LOG_LANGUAGE_SET, $lang );
-                if ( !exists $self->_hyphenators->{$lang} ) {
-                    $self->_add_tex_hyphen_to_cache();
-                }
-            }
-        },
+        code => \&__configure_lang,
         view => 'PRIVATE',
     );
 
     method _add_tex_hyphen_to_cache => (
-        code => sub {
-            my ($self) = @_;
-            my $thp = TeX::Hyphen::Pattern->new();
-            $thp->label( $self->_lang );
-            my $cache = $self->_hyphenators;
-            if ( my $file = $thp->filename ) {
-                $log->debug( sprintf $LOG_PATTERN_FILE, $file );
-                ${$cache}{ $self->_lang } = TeX::Hyphen->new(
-                    file     => $file,
-                    leftmin  => $self->min_pre,
-                    rightmin => $self->min_post,
-                );
-                $self->_hyphenators($cache);
-            }
-        },
+        code => \&__add_tex_hyphen_to_cache,
         view => 'PRIVATE',
     );
 
     method _hyphenable_by_class => (
-        code => sub {
-            my ( $self, $element ) = @_;
-            my $included_level = $ONE_LEVEL_UP;
-            my $excluded_level = $ONE_LEVEL_UP;
-            $self->default_included && $excluded_level--;
-            $self->default_included || $included_level--;
-
-            $included_level =
-              $self->_get_nearest_ancestor_level_by_classname( $element,
-                $self->classes_included, $included_level );
-            $excluded_level =
-              $self->_get_nearest_ancestor_level_by_classname( $element,
-                $self->classes_excluded, $excluded_level );
-            return !( $excluded_level > $included_level );
-        },
+        code => \&__hyphenable_by_class,
         view => 'PRIVATE',
     );
 
     method _hyphenable => (
-        code => sub {
-            my ( $self, $element ) = @_;
-            return !( $element->is_inside($NOBR)
-                || $element->is_inside($PRE)
-                || $element->look_up( $NOWRAP, $ANYTHING )
-                || $element->look_up( $STYLE,  $STYLE_NOWRAP )
-                || !$self->_hyphenable_by_class($element) );
-        },
+        code => \&__hyphenable,
         view => 'PRIVATE',
     );
 
     method _get_nearest_ancestor_level_by_classname => (
-        code => sub {
-            my ( $self, $element, $ar_classnames, $level ) = @_;
-            my $classnames = Set::Scalar->new( @{$ar_classnames} );
-            $log->debug( sprintf $LOG_LOOKING_UP, $classnames->size );
-
-            # Only looking up the tree if there is something to look for:
-            if (
-                $classnames
-                && (
-                    my $container = $element->look_up(
-                        $CLASS => $ANYTHING,
-                        sub {
-                            $_[0] && $classnames->has( $_[0]->attr($CLASS) );
-                        }
-                    )
-                )
-              )
-            {
-                $level = $container->depth;
-            }
-            return $level;
-
-        },
+        code => \&__get_nearest_ancestor_level_by_classname,
         view => 'PRIVATE',
     );
 
     method _reset_tree => (
-        code => sub {
-            my ($self) = @_;
-            $self->_tree && $self->_tree( $self->_tree->delete );
-            my $tree = HTML::TreeBuilder->new();
-            $tree->warn(1);
-            $tree->store_pis(1);
-            $self->_tree($tree);
-        },
+        code => \&__reset_tree,
         view => 'PRIVATE',
     );
 
 };
 
+sub __hyphenated {
+    my ( $self, $html ) = @_;
+    if ( defined $html ) {
+        $log->debug( sprintf $LOG_HTML_METHOD, $html );
+        $self->html($html);
+    }
+    else {
+        $log->debug( sprintf $LOG_HTML_PROPERTY, $self->html );
+    }
+    if ( defined $self->html ) {
+        $self->_traverse_html();
+        return $self->_clean_html();
+    }
+    $log->warn($LOG_HTML_UNDEF);
+    return;
+}
+
+sub __traverse_html {
+    my ($self) = @_;
+    $self->_reset_tree;
+    $self->_tree->parse_content( $self->html );
+    $self->_tree->objectify_text();
+    $self->_tree->traverse(
+        [
+            sub {
+                my $element = $_[0];
+                $log->debug( sprintf $LOG_TRAVERSE, $element->tag() );
+                $self->_configure_lang($element);
+                if ( $element->attr($TEXT) ) {
+                    if ( $self->_hyphenable($element) ) {
+                        $log->debug( sprintf $LOG_TEXT_NODE,
+                            $element->attr($TEXT) );
+                        $element->attr( $TEXT,
+                            $self->_hyphen( $element->attr($TEXT) ) );
+                    }
+                }
+                else {
+                    foreach my $attr ( $element->all_external_attr_names() ) {
+                        if ( $text_attr->has($attr) ) {
+                            $element->attr( $attr,
+                                $self->_hyphen( $element->attr($attr) ) );
+                        }
+                    }
+                }
+                ## no critic qw(RequireExplicitInclusion ProhibitCallsToUnexportedSubs)
+                return HTML::Element::OK;
+                ## use critic
+            },
+            undef
+        ]
+    );
+    return;
+}
+
+sub __clean_html {
+    my ($self) = @_;
+    $self->_tree->deobjectify_text();
+    my $html =
+        $self->output_xml
+      ? $self->_tree->as_XML()
+      : $self->_tree->as_HTML( $HTML_ESCAPE, $EMPTY, {} );
+    $self->_reset_tree;
+    $html =~ s/$ROOT/$1/xgism;
+    return $html;
+}
+
+sub __hyphen {
+    my ( $self, $text ) = @_;
+    $log->debug( sprintf $LOG_HYPHEN_TEXT, $text );
+    $text =~ s/(\w{@{[$self->min_length]},})/$self->_hyphen_word($1)/xsmeg;
+    return $text;
+}
+
+sub __hyphen_word {
+    my ( $self, $word ) = @_;
+    if ( defined $self->_hyphenators->{ $self->_lang } ) {
+        $log->debug( sprintf $LOG_HYPHEN_WORD,
+            $word, $self->_hyphenators->{ $self->_lang }->visualize($word) );
+        my $number = 0;
+        foreach
+          my $pos ( $self->_hyphenators->{ $self->_lang }->hyphenate($word) )
+        {
+            substr $word, $pos + $number, 0, $SOFT_HYPHEN;
+            $number += length $SOFT_HYPHEN;
+        }
+    }
+    else {
+        $log->warn( sprintf $LOG_NOT_HYPHEN, $self->_lang );
+    }
+    return $word;
+}
+
+sub __configure_lang {
+    my ( $self, $element ) = @_;
+    my $lang = $element->attr_get_i($LANG);
+    $lang ||= $element->attr_get_i(qq{xml:$LANG});
+    my %hyphen_opts = (
+        leftmin  => $self->min_pre,
+        rightmin => $self->min_post,
+    );
+    defined $self->style
+      && ( $hyphen_opts{style} = $self->style );
+    defined $lang || ( $lang = $self->default_lang );
+    if ( !defined $self->_lang || $lang ne $self->_lang ) {
+        $self->_lang($lang);
+        $log->debug( sprintf $LOG_LANGUAGE_SET, $lang );
+        if ( !exists $self->_hyphenators->{$lang} ) {
+            $self->_add_tex_hyphen_to_cache();
+        }
+    }
+    return;
+}
+
+sub __add_tex_hyphen_to_cache {
+    my ($self) = @_;
+    my $thp = TeX::Hyphen::Pattern->new();
+    $thp->label( $self->_lang );
+    my $cache = $self->_hyphenators;
+    if ( my $file = $thp->filename ) {
+        $log->debug( sprintf $LOG_PATTERN_FILE, $file );
+        ${$cache}{ $self->_lang } = TeX::Hyphen->new(
+            file     => $file,
+            leftmin  => $self->min_pre,
+            rightmin => $self->min_post,
+        );
+        $self->_hyphenators($cache);
+    }
+    return;
+}
+
+sub __hyphenable_by_class {
+    my ( $self, $element ) = @_;
+    my $included_level = $ONE_LEVEL_UP;
+    my $excluded_level = $ONE_LEVEL_UP;
+    $self->default_included && $excluded_level--;
+    $self->default_included || $included_level--;
+
+    $included_level =
+      $self->_get_nearest_ancestor_level_by_classname( $element,
+        $self->classes_included, $included_level );
+    $excluded_level =
+      $self->_get_nearest_ancestor_level_by_classname( $element,
+        $self->classes_excluded, $excluded_level );
+    return !( $excluded_level > $included_level );
+}
+
+sub __hyphenable {
+    my ( $self, $element ) = @_;
+    return !( $element->is_inside($NOBR)
+        || $element->is_inside($PRE)
+        || $element->look_up( $NOWRAP, $ANYTHING )
+        || $element->look_up( $STYLE,  $STYLE_NOWRAP )
+        || !$self->_hyphenable_by_class($element) );
+}
+
+sub __get_nearest_ancestor_level_by_classname {
+    my ( $self, $element, $ar_classnames, $level ) = @_;
+    my $classnames = Set::Scalar->new( @{$ar_classnames} );
+    $log->debug( sprintf $LOG_LOOKING_UP, $classnames->size );
+
+    # Only looking up the tree if there is something to look for:
+    if (
+        $classnames
+        && (
+            my $container = $element->look_up(
+                $CLASS => $ANYTHING,
+                sub {
+                    $_[0]
+                      && $classnames->has( $_[0]->attr($CLASS) );
+                }
+            )
+        )
+      )
+    {
+        $level = $container->depth;
+    }
+    return $level;
+
+}
+
+sub __reset_tree {
+    my ($self) = @_;
+    $self->_tree && $self->_tree( $self->_tree->delete );
+    my $tree = HTML::TreeBuilder->new();
+    $tree->warn(1);
+    $tree->store_pis(1);
+    $self->_tree($tree);
+    return;
+}
+
+
 1;
 
 __END__
 
 =encoding utf8
 
+=for stopwords Ipenburg Readonly
+
 =head1 NAME
 
 HTML::Hyphenate - class for inserting soft hyphens into HTML.
 
 =head1 VERSION
 
-This is version 0.04.
+This is version 0.05.
 
 =head1 SYNOPSIS
 
@@ -342,12 +362,12 @@ This is version 0.04.
     $hyphenator = new HTML::Hyphenate();
     $html_with_soft_hyphens = $hyphenator->hyphenated($html);
 
-	$hyphenator->html($html);
-	$hyphenator->style($style); # czech or german
+    $hyphenator->html($html);
+    $hyphenator->style($style); # czech or german
 
-	$hyphenator->min_length(10);
-	$hyphenator->min_pre(2);
-	$hyphenator->min_post(2);
+    $hyphenator->min_length(10);
+    $hyphenator->min_pre(2);
+    $hyphenator->min_post(2);
     $hyphenator->output_xml(1);
     $hyphenator->default_lang('en-us');
     $hyphenator->default_included(1);
@@ -398,7 +418,7 @@ last soft hyphen. Defaults to 2 characters.
 
 =item $hyphenator->output_xml(1);
 
-Have L<HTML::TreeBuilder|HTML::TreeBuilder> output HTML in HTML or XML modus. 
+Have L<HTML::TreeBuilder|HTML::TreeBuilder> output HTML in HTML or XML mode. 
 
 =item $hyphenator->default_lang('en-us');
 
@@ -413,12 +433,13 @@ specific class names.
 
 =item $hyphenator->classes_included();
 
-Gets or sets an arrayref of class names that will have soft hyphens inserted.
+Gets or sets a reference to an array of class names that will have soft
+hyphens inserted.
 
 =item $hyphenator->classes_excluded();
 
-Gets or sets an arrayref of class names that will not have soft hyphens
-inserted.
+Gets or sets a reference to an array of class names that will not have soft
+hyphens inserted.
 
 =back
 
@@ -464,21 +485,21 @@ TeX::Hyphen::Pattern
 =item * Empty subclass test fails, this is probably a Class::Meta::Express
 issue. The empty subclass can't be empty, it needs at least:
 
-	use Class::Meta::Express;
+    use Class::Meta::Express;
 
-	class {
-		ctor 'new';
-	};
+    class {
+        ctor 'new';
+    };
 
 =item * Perfect hyphenation can be more complicated than just inserting a
 hyphen somewhere in a word, and sometimes requires semantics to get it right.
-For example "cafeetje" should be hyphenated as "cafe-tje" and not "cafee-tje"
-and "buurtje" can be hyphenated as "buur-tje" or "buurt-je", depending on it's
-meaning. While HTML could provide a bit more context (mainly the language
-being used) than plain text to handle these issues, the initial purpose of
-this module is to make it possible for HTML rendering engines that support
-soft hyphens to be able to break long words over multiple lines to avoid
-unwanted overflow.
+For example C<cafeetje> should be hyphenated as C<cafe-tje> and not
+C<cafee-tje> and C<buurtje> can be hyphenated as C<buur-tje> or C<buurt-je>,
+depending on it's meaning. While HTML could provide a bit more context (mainly
+the language being used) than plain text to handle these issues, the initial
+purpose of this module is to make it possible for HTML rendering engines that
+support soft hyphens to be able to break long words over multiple lines to
+avoid unwanted overflow.
 
 =item * The hyphenation doesn't get better than TeX::Hyphenate and it
 hyphenation patterns provide.
